@@ -2,15 +2,16 @@
 
 package Validation::Class;
 {
-    $Validation::Class::VERSION = '7.58';
+    $Validation::Class::VERSION = '7.65';
 }
 
 use strict;
 use warnings;
 
-our $VERSION = '7.58';    # VERSION
+our $VERSION = '7.65';    # VERSION
 
 use Module::Find;
+use Module::Runtime 'use_module';
 use Carp 'confess';
 use Hash::Merge 'merge';
 use Exporter ();
@@ -101,13 +102,13 @@ use Validation::Class::Prototype;
 
     sub configure_class_proto {
 
-        my $configuration_routine = shift;
+        my $configuration_routine = pop;
 
         return undef unless "CODE" eq ref $configuration_routine;
 
         no strict 'refs';
 
-        my $proto = return_class_proto;
+        my $proto = return_class_proto shift;
 
         $configuration_routine->($proto);
 
@@ -165,6 +166,8 @@ sub has { goto &attribute }
 
 sub attribute {
 
+    my $package = shift if @_ == 3;
+
     my ($attrs, $default) = @_;
 
     return unless $attrs;
@@ -209,7 +212,7 @@ sub attribute {
 
         }
 
-        return configure_class_proto sub {
+        return configure_class_proto $package => sub {
 
             my ($proto) = @_;
 
@@ -231,11 +234,13 @@ sub bld { goto &build }
 
 sub build {
 
+    my $package = shift if @_ == 2;
+
     my ($code) = @_;
 
     return undef unless ("CODE" eq ref $code);
 
-    return configure_class_proto sub {
+    return configure_class_proto $package => sub {
 
         my ($proto) = @_;
 
@@ -252,11 +257,13 @@ sub dir { goto &directive }
 
 sub directive {
 
+    my $package = shift if @_ == 3;
+
     my ($name, $data) = @_;
 
     return undef unless ($name && $data);
 
-    return configure_class_proto sub {
+    return configure_class_proto $package => sub {
 
         my ($proto) = @_;
 
@@ -279,6 +286,8 @@ sub fld { goto &field }
 
 sub field {
 
+    my $package = shift if @_ == 3;
+
     my ($name, $data) = @_;
 
     return undef unless ($name && $data);
@@ -287,7 +296,7 @@ sub field {
       unless $name =~ /^[a-zA-Z_](([\w\.]+)?\w)$/ xor $name
           =~ /^[a-zA-Z_](([\w\.]+)?\w)\:\d+$/;
 
-    return configure_class_proto sub {
+    return configure_class_proto $package => sub {
 
         my ($proto) = @_;
 
@@ -342,11 +351,13 @@ sub flt { goto &filter }
 
 sub filter {
 
+    my $package = shift if @_ == 3;
+
     my ($name, $data) = @_;
 
     return undef unless ($name && $data);
 
-    return configure_class_proto sub {
+    return configure_class_proto $package => sub {
 
         my ($proto) = @_;
 
@@ -363,9 +374,71 @@ sub set { goto &load }
 
 sub load {
 
-    my $data = @_ % 2 ? $_[0] || {} : {@_};
+    my $package;
+    my $data;
 
-    return configure_class_proto sub {
+    # handle different types of invocations
+
+    # 1   - load({})
+    # 2+  - load(a => b)
+    # 2+  - package->load({})
+    # 3+  - package->load(a => b)
+
+    # --
+
+    # load({})
+
+    if (@_ == 1) {
+
+        if ("HASH" eq ref $_[0]) {
+
+            $data = shift;
+
+        }
+
+    }
+
+    # load(a => b)
+    # package->load({})
+
+    elsif (@_ == 2) {
+
+        if ("HASH" eq ref $_[-1]) {
+
+            $package = shift;
+            $data    = shift;
+
+        }
+
+        else {
+
+            $data = {@_};
+
+        }
+
+    }
+
+    # load(a => b)
+    # package->load(a => b)
+
+    elsif (@_ >= 3) {
+
+        if (@_ % 2) {
+
+            $package = shift;
+            $data    = {@_};
+
+        }
+
+        else {
+
+            $data = {@_};
+
+        }
+
+    }
+
+    return configure_class_proto $package => sub {
 
         my ($proto) = @_;
 
@@ -429,13 +502,7 @@ sub load {
 
                 $plugin =~ s/^\+//;
 
-                # require plugin
-                my $file = $plugin;
-                $file =~ s/::/\//g;
-                $file .= ".pm";
-
-                eval "require $plugin"
-                  unless $INC{$file};    # unless already loaded
+                use_module $plugin;
 
             }
 
@@ -444,6 +511,7 @@ sub load {
         }
 
         # attach roles
+
         if (grep { $data->{$_} } qw/base bases role roles/) {
 
             my @roles;
@@ -452,7 +520,7 @@ sub load {
                  $data->{base}
               || $data->{role}
               || $data->{roles}
-              || $data->{bases};
+              || $data->{bases};    # backwards compat
 
             if ($alias) {
 
@@ -464,22 +532,17 @@ sub load {
 
                 foreach my $role (@roles) {
 
-                    # require plugin
-                    my $file = $role;
-                    $file =~ s/::/\//g;
-                    $file .= ".pm";
+                    use_module $role;
 
                     no strict 'refs';
 
-                    eval "require $role"
-                      unless $INC{$file};    # unless already loaded
-
                     my @routines = grep { defined &{"$role\::$_"} }
                       keys %{"$role\::"};
 
                     if (@routines) {
 
                         # copy methods
+
                         foreach my $routine (@routines) {
 
                             eval {
@@ -489,8 +552,6 @@ sub load {
 
                             } unless $proto->{package}->can($routine);
 
-                            # maybe I should issue a warning?
-
                         }
 
                         my $role_proto = return_class_proto $role;
@@ -499,6 +560,7 @@ sub load {
                         $role_proto->{config} ||= {};    # good measure
 
                         # merge configs
+
                         $proto->{config} = merge $proto->{config},
                           $role_proto->{config};
 
@@ -519,11 +581,13 @@ sub mth { goto &method }
 
 sub method {
 
+    my $package = shift if @_ == 3;
+
     my ($name, $data) = @_;
 
     return undef unless ($name && $data);
 
-    return configure_class_proto sub {
+    return configure_class_proto $package => sub {
 
         my ($proto) = @_;
 
@@ -644,11 +708,13 @@ sub mxn { goto &mixin }
 
 sub mixin {
 
+    my $package = shift if @_ == 3;
+
     my ($name, $data) = @_;
 
     return undef unless ($name && $data);
 
-    return configure_class_proto sub {
+    return configure_class_proto $package => sub {
 
         my $proto = shift;
 
@@ -665,7 +731,7 @@ sub new {
 
     my $class = shift;
 
-    my $proto = return_class_proto $class;
+    my $proto = return_class_proto ref $class || $class;
 
     my $config = $proto->{config};
 
@@ -720,7 +786,7 @@ sub new {
 
     foreach my $builder (@{$config->{BUILDERS}}) {
 
-        $builder->($self);
+        $builder->($self, %ARGS);
 
     }
 
@@ -740,11 +806,13 @@ sub obj { goto &object }
 
 sub object {
 
+    my $package = shift if @_ == 3;
+
     my ($name, $data) = @_;
 
     return undef unless ($name && $data);
 
-    return configure_class_proto sub {
+    return configure_class_proto $package => sub {
 
         my ($proto) = @_;
 
@@ -802,11 +870,13 @@ sub pro { goto &profile }
 
 sub profile {
 
+    my $package = shift if @_ == 3;
+
     my ($name, $data) = @_;
 
     return undef unless ($name && "CODE" eq ref $data);
 
-    return configure_class_proto sub {
+    return configure_class_proto $package => sub {
 
         my ($proto) = @_;
 
@@ -842,7 +912,7 @@ Validation::Class - Self-Validating Object System and Data Validation Framework
 
 =head1 VERSION
 
-version 7.58
+version 7.65
 
 =head1 SYNOPSIS
 
@@ -1343,13 +1413,9 @@ constructs.
             my ($self) = @_;
             
             my @conn_str_parts =
-                ('dbi', 'mysql', $self->name, $self->host, $self->port);
+                ('dbi', 'mysql', map { $self->$_ } qw(name host port));
             
-            return (
-                join(':', @conn_str_parts),
-                $self->user,
-                $self->pass
-            )
+            return (join(':', @conn_str_parts), $self->user, $self->pass);
             
         }
     };
